import { HttpService } from '@nestjs/axios'
import { Injectable } from '@nestjs/common'
import { lastValueFrom } from 'rxjs'

import { ServiceResponse } from '@/response/response.interface'
import { HttpStatusCode } from '@/response/status-code.enum'

@Injectable()
export class ChatManagementHttpService {
  private readonly baseUrl = 'http://192.168.206.189:4090/api'

  constructor(private readonly httpService: HttpService) {}

  private async makeRequest<T>(
    endpoint: string,
    params?: Record<string, any>
  ): Promise<ServiceResponse<T>> {
    try {
      const url = `${this.baseUrl}/${endpoint}`
      const responseObservable = await this.httpService.get<ServiceResponse<T>>(
        url,
        { params }
      )
      const { data } = await lastValueFrom(responseObservable)
      return data
    } catch (error) {
      return {
        code: HttpStatusCode.INTERNAL_SERVER_ERROR,
        msg: error.message,
        data: null as T
      }
    }
  }

  async makeRequestPost<T>(
    endpoint: string,
    params?: Record<string, any>
  ): Promise<ServiceResponse<T>> {
    try {
      const url = `${this.baseUrl}/${endpoint}`
      const responseObservable = await this.httpService.post<
        ServiceResponse<T>
      >(url, params, {
        headers: {
          'Content-Type': 'application/json'
        }
      })
      const { data } = await lastValueFrom(responseObservable)
      return data
    } catch (error) {
      return {
        code: HttpStatusCode.INTERNAL_SERVER_ERROR,
        msg: error.message,
        data: null as T
      }
    }
  }

  // 获取对话总览列表
  async getStaffSessionSummary(
    staff_id?: string,
    status?: string,
    page?: number,
    size?: number
  ): Promise<ServiceResponse<StaffSummary[]>> {
    return this.makeRequest<StaffSummary[]>('getStaffSessionSummary', {
      staff_id,
      status,
      page,
      size
    })
  }

  // 获取客服人员列表
  async getStaffList(
    page?: number,
    size?: number
  ): Promise<ServiceResponse<ChatStaff[]>> {
    return this.makeRequest<ChatStaff[]>('getStaffList', {
      page,
      size
    })
  }

  // 获取客服对话列表
  async getStaffSessionList(
    staff_id: string,
    page?: number,
    page_size?: number
  ): Promise<ServiceResponse<StaffSession[]>> {
    return this.makeRequest<StaffSession[]>('getStaffSessionList', {
      staff_id,
      page,
      page_size
    })
  }

  // 获取客服微信对话详情列表
  async getConversationList(
    customer_id: string,
    staff_id: string,
    status?: number,
    page?: number,
    size?: number
  ): Promise<ServiceResponse<ChatConversation[]>> {
    return this.makeRequest<ChatConversation[]>('getConversationList', {
      customer_id,
      staff_id,
      status,
      page,
      size
    })
  }
}
